@@ -11,7 +11,7 @@
 #
 
 "Kb" <-
-function(S=35,T=25,P=0,pHscale="T",kSWS2scale=0,ktotal2SWS_P0=0,warn="y"){
+function(S=35,T=25,P=0,pHscale="T",kSWS2scale="x",ktotal2SWS_P0="x",warn="y"){
 
     nK <- max(length(S), length(T), length(P), length(pHscale), length(kSWS2scale) ,length(ktotal2SWS_P0))
 
@@ -47,7 +47,7 @@ function(S=35,T=25,P=0,pHscale="T",kSWS2scale=0,ktotal2SWS_P0=0,warn="y"){
     ## ---- Conversion from Total scale to seawater scale before pressure corrections
     
     # if correction factor (from Total scale to seawater at P=0) not given
-    if (missing(ktotal2SWS_P0))
+    if (missing(ktotal2SWS_P0) || ktotal2SWS_P0[1] == "x")
     {
         # Compute it
         ktotal2SWS_P0 <- kconv(S=S, T=T, P=0)$ktotal2SWS
@@ -71,7 +71,7 @@ function(S=35,T=25,P=0,pHscale="T",kSWS2scale=0,ktotal2SWS_P0=0,warn="y"){
     if (any(is_total) || any(is_free))
     {
         # if pH scale correction factor not given
-        if (missing(kSWS2scale))
+        if (missing(kSWS2scale) || kSWS2scale[1] == "x")
         {
             # Compute it
             kSWS2scale <- rep(1.0,nK)
